@@ -3,11 +3,13 @@
 #' @export
 detectFronts.RasterLayer <- function(x, method = "BelkinOReilly2009", intermediate = FALSE, ...){
 
+  checkArgs_df_RasterLayer(x = x)
+
   # Extract coordinates and data for calculate fronts from Raster and convert to list
   startMatrix <- values(x)
   startMatrix <- list(x = seq(from = x@extent@xmin, to = x@extent@xmax, length.out = x@ncols),
                       y = seq(from = x@extent@ymin, to = x@extent@ymax, length.out = x@nrows),
-                      z = startMatrix)
+                      z = matrix(data = startMatrix, nrow = x@ncols))
 
   allOuts <- detectFronts(x = startMatrix, method = method, intermediate = intermediate, ...)
 
