@@ -3,6 +3,10 @@
 #' @export
 detectFronts.matrix <- function(x, method = "BelkinOReilly2009", intermediate = FALSE, ...){
 
+  # Check arguments
+  checkArgs_df_matrix(x = x)
+
+  # Apply method
   output <- detectFronts.default(x = x, method = method, intermediate = intermediate, ...)
 
   return(output)
